@@ -5,6 +5,7 @@ import subprocess as sp
 from pypresence import Presence
 from pypresence.exceptions import DiscordNotFound
 
+
 from .history import history
 from .misc import get_anime_info, error
 from .colors import colors
@@ -32,10 +33,10 @@ def start_player(entry, rpc_client=None, player=None):
         player_command = [
             f"{player}",
             f"{entry.stream_url}",
-            "--" if player == "syncplay" else "",
+             "--" if player == "syncplay" else "",
             f"--force-media-title={media_title}",
             f"--referrer={entry.embed_url}",
-            "--force-window=immediate",
+             "--force-window=immediate",
         ]
 
         for x in config.mpv_commandline_options:
@@ -75,6 +76,33 @@ def start_player(entry, rpc_client=None, player=None):
 
     return sub_proc
 
+def create_mpv_controllable():
+    import mpv
+    player = mpv.MPV(
+        input_default_bindings=True,
+        input_vo_keyboard=True,
+        force_window="immediate",
+    )
+
+    return player
+
+def mpv_start_stream(entry, player, rpc_client=None):
+    media_title = (
+        entry.show_name + " - Episode: " + str(entry.ep) + " - " + str(entry.quality)
+    )
+
+    player.referrer = entry.embed_url
+    player.force_media_title = media_title
+    player.play(entry.stream_url)
+
+    hist_class = history(entry)
+    hist_class.write_hist()
+
+    if config.dc_presence:
+        dc_media_title = f"{entry.show_name} | {entry.ep}/{entry.latest_ep}"
+        dc_presence(dc_media_title, entry.category_url, rpc_client)
+
+    return player
 
 def dc_presence_connect():
     CLIENT_ID = 966365883691855942
@@ -105,4 +133,4 @@ def dc_presence(media_title, category_url, rpc_client):
 
 
 # backwards-compatability
-mpv = start_player
+#mpv = start_player
